==> twei-0.2.0.tgz: package/lib/alias.js <==
var fs = require('fs')
  , path = require('path')
  ;


var alias = {}

//twei 定义命令. 
//alias: 定义微博命令简称
  , tAlias = {
  
      update: 'execute status.update'
    , repost: {
        alias: ['rt', 'retweet']
      , cmd: 'execute status.repost'
    }
    , status: {
        cmd: 'execute statuses.user count=5'
      , apis: 'status'
    }
    
    //查看用户
    , user: {
        cmd: 'execute user'
      , alias: 'whois'
    }
    
    , followers: 'execute friends.followers'
    , friends: {
        cmd: 'execute friends.friends'
      , apis: 'friends'
    }
    
    , follow: 'execute friends.create'
    , unfollow: 'execute friends.destroy'
    
    , timeline: {
        cmd: 'execute statuses.user count=5'
      , apis: 'statuses'
    }
    
    , comment: {
        cmd: 'execute comment.comment'
      , apis: 'comment'
    }
    
    , comments: {
        cmd: 'execute comment.show'
      , apis: 'comments'
    }
  }
  ;

alias = objMerge(alias, tAlias);

//用户自定义命令
var uAlias = fs.readdirSync(__dirname + '/user_alias');
uAlias.forEach(function(fileName){
  if('.js' == path.extname(fileName)){
    alias = objMerge(alias, require('./user_alias/' + fileName));
  }
});

/**
 * restore alias to core command
 * @param {Object} cmdmap aliasmap
 * @return {Object} 返回完整的 名称:命令 对象
      Example: 
        {
            update: ''execute status.update''
          , user: 'execute user.show'
          , whois: 'execute user.show'
        }
 */
function aliasExpand(cmdmap){
  var cmds = {}
    , twei = require('../')
    , alias, apiGroup
    ;

  for(var key in cmdmap){
    alias = cmdmap[key];
    if(alias.alias){
      if(Array.isArray(alias.alias)){
        for(var i = 0, l = alias.alias.length; i < l; i++){
          cmds[alias.alias[i]] = cmdmap[key].cmd;
        }
      }else{
        cmds[alias.alias] = cmdmap[key].cmd;
      }
      cmds[key] = cmdmap[key].cmd;
      delete alias.alias;
    }else{
      cmds[key] = cmdmap[key].cmd || cmdmap[key];
    }
    
    if(alias.apis && typeof (apiGroup = twei.getApiGroup(alias.apis)) == 'object'){
      for(var apiName in apiGroup){
        if(!cmds[key + '.' + apiName]){
          cmds[key + '.' + apiName] = 'execute ' + alias.apis + '.' + apiName;
        }
      }
    }
  }
  //console.log(cmds);
  return cmds;
}


function objMerge(o1, o2){
  var o3 = {};
  for(var key in o1){
    o3[key] = o1[key]
  }
  for (var key in o2){
    o3[key] = o2[key]
  }
  return o3;
}

module.exports = aliasExpand(alias);

==> twei-0.2.1.tgz: package/lib/alias.js <==
var fs = require('fs')
  , path = require('path')
  ;


var alias = {}

//twei 定义命令. 
//alias: 定义微博命令简称
  , tAlias = {
  
      update: 'execute status.update'
    , repost: {
        alias: ['rt', 'retweet']
      , cmd: 'execute status.repost'
    }
    , status: {
        cmd: 'execute statuses.user count=5'
      , apis: 'status'
    }
    
    //查看用户
    , user: {
        cmd: 'execute user'
      , alias: 'whois'
    }
    
    , followers: 'execute friends.followers'
    , friends: {
        cmd: 'execute friends.friends'
      , apis: 'friends'
    }
    
    , follow: 'execute friends.create'
    , unfollow: 'execute friends.destroy'
    
    , timeline: {
        cmd: 'execute statuses.home count=5'
      , apis: 'statuses'
    }
    
    , comment: {
        cmd: 'execute comment.comment'
      , apis: 'comment'
    }
    
    , comments: {
        cmd: 'execute comments.show'
      , apis: 'comments'
    }
    , remind: 'execute remind'
  }
  ;

alias = objMerge(alias, tAlias);

//用户自定义命令
var uAlias = fs.readdirSync(__dirname + '/user_alias');
uAlias.forEach(function(fileName){
  if('.js' == path.extname(fileName)){
    alias = objMerge(alias, require('./user_alias/' + fileName));
  }
});

/**
 * restore alias to core command
 * @param {Object} cmdmap aliasmap
 * @return {Object} 返回完整的 名称:命令 对象
      Example: 
        {
            update: ''execute status.update''
          , user: 'execute user.show'
          , whois: 'execute user.show'
        }
 */
function aliasExpand(cmdmap){
  var cmds = {}
    , twei = require('../')
    , alias, apiGroup
    ;

  for(var key in cmdmap){
    alias = cmdmap[key];
    if(alias.alias){
      if(Array.isArray(alias.alias)){
        for(var i = 0, l = alias.alias.length; i < l; i++){
          cmds[alias.alias[i]] = cmdmap[key].cmd;
        }
      }else{
        cmds[alias.alias] = cmdmap[key].cmd;
      }
      cmds[key] = cmdmap[key].cmd;
      delete alias.alias;
    }else{
      cmds[key] = cmdmap[key].cmd || cmdmap[key];
    }
    
    if(alias.apis && typeof (apiGroup = twei.getApiGroup(alias.apis)) == 'object'){
      for(var apiName in apiGroup){
        if(!cmds[key + '.' + apiName]){
          cmds[key + '.' + apiName] = 'execute ' + alias.apis + '.' + apiName;
        }
      }
    }
  }
  //console.log(cmds);
  return cmds;
}


function objMerge(o1, o2){
  var o3 = {};
  for(var key in o1){
    o3[key] = o1[key]
  }
  for (var key in o2){
    o3[key] = o2[key]
  }
  return o3;
}

module.exports = aliasExpand(alias);
